API Reference (auto-generated)
==============================

Morphological Analyzer
----------------------

.. automodule:: pymorphy2.analyzer
    :members:
    :undoc-members:

Analyzer units
~~~~~~~~~~~~~~

.. automodule:: pymorphy2.units.by_lookup
    :members:

.. automodule:: pymorphy2.units.by_analogy
    :members:

.. automodule:: pymorphy2.units.by_hyphen
    :members:

.. automodule:: pymorphy2.units.by_shape
    :members:

Tagset
------

.. automodule:: pymorphy2.tagset
    :members: OpencorporaTag

.. _cli:

Command-Line Interface
----------------------

.. automodule:: pymorphy2.cli

Utilities for OpenCorpora Dictionaries
--------------------------------------

.. automodule:: pymorphy2.opencorpora_dict.wrapper
    :members:

Various Utilities
-----------------

.. automodule:: pymorphy2.tokenizers
    :members:

.. automodule:: pymorphy2.shapes
    :members:

.. automodule:: pymorphy2.utils
    :members:
